@@ -1,4 +1,4 @@
-# Copyright 2022 Q-CTRL. All rights reserved.
+# Copyright 2023 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -57,25 +57,6 @@ def plot_controls(
         that control, or (2) a list of segments, each a dictionary with 'duration' and 'value' keys.
         The durations must be in seconds and the values (possibly complex) in the units specified by
         `unit_symbol`.
-        For example, the following two ``controls`` inputs would be valid (and equivalent)::
-
-            controls={
-              "Clock": {"durations": [1.0, 1.0, 2.0], "values": [-0.5, 0.5, -1.5]},
-              "Microwave": {"durations": [0.5, 1.0], "values": [0.5 + 1.5j, 0.2 - 0.3j]},
-            }
-
-            controls={
-              "Clock": [
-                {"duration": 1.0, "value": -0.5},
-                {"duration": 1.0, "value": 0.5},
-                {"duration": 2.0, "value": -1.5},
-              ],
-              "Microwave": [
-                {"duration": 0.5, "value": 0.5 + 1.5j},
-                {"duration": 1.0, "value": 0.2 - 0.3j},
-              ],
-            }
-
     polar : bool, optional
         The mode of the plot when the values appear to be complex numbers.
         Plot magnitude and angle in two figures if set to True, otherwise plot I and Q
@@ -91,6 +72,27 @@ def plot_controls(
     figure : matplotlib.figure.Figure, optional
         A matplotlib Figure in which to place the plots.
         If passed, its dimensions and axes will be overridden.
+
+    Notes
+    -----
+    As an example, the following are valid (and equivalent) ``control`` inputs ::
+
+        controls={
+            "Clock": {"durations": [1.0, 1.0, 2.0], "values": [-0.5, 0.5, -1.5]},
+            "Microwave": {"durations": [0.5, 1.0], "values": [0.5 + 1.5j, 0.2 - 0.3j]},
+        }
+
+        controls={
+            "Clock": [
+                {"duration": 1.0, "value": -0.5},
+                {"duration": 1.0, "value": 0.5},
+                {"duration": 2.0, "value": -1.5},
+            ],
+            "Microwave": [
+                {"duration": 0.5, "value": 0.5 + 1.5j},
+                {"duration": 1.0, "value": 0.2 - 0.3j},
+            ],
+        }
     """
 
     boulder_opal_advice = (
@@ -247,27 +249,6 @@ def plot_smooth_controls(
         that control, or (2) a list of samples, each a dictionary with 'time' and 'value' keys.
         The times must be in seconds and the values (possibly complex) in the units specified by
         `unit_symbol`.
-        For example, the following two ``controls`` inputs would be valid (and equivalent)::
-
-            controls={
-              "Clock": {"times": [0.0, 0.5, 1.5, 2.0], "values": [0.1, 0.3, 0.2, 0.4]},
-              "Microwave": {"times": [0.0, 1.0, 2.0], "values": [0.5 + 0.5j, 0.3, 0.2 - 0.3j]},
-            }
-
-            controls={
-              "Clock": [
-                {"time": 0.0, "value": 0.1},
-                {"time": 0.5, "value": 0.3},
-                {"time": 1.5, "value": 0.2},
-                {"time": 2.0, "value": 0.4},
-              ],
-              "Microwave": [
-                {"time": 0.0, "value": 0.5 + 0.5j},
-                {"time": 1.0, "value": 0.3},
-                {"time": 2.0, "value": 0.2 - 0.3j},
-              ],
-            }
-
     polar : bool, optional
         The mode of the plot when the values appear to be complex numbers.
         Plot magnitude and angle in two figures if set to True, otherwise plot I and Q
@@ -280,6 +261,29 @@ def plot_smooth_controls(
     figure : matplotlib.figure.Figure, optional
         A matplotlib Figure in which to place the plots.
         If passed, its dimensions and axes will be overridden.
+
+    Notes
+    -----
+    As an example, the following are valid (and equivalent) ``control`` inputs ::
+
+        controls={
+            "Clock": {"times": [0.0, 0.5, 1.5, 2.0], "values": [0.1, 0.3, 0.2, 0.4]},
+            "Microwave": {"times": [0.0, 1.0, 2.0], "values": [0.5 + 0.5j, 0.3, 0.2 - 0.3j]},
+        }
+
+        controls={
+            "Clock": [
+                {"time": 0.0, "value": 0.1},
+                {"time": 0.5, "value": 0.3},
+                {"time": 1.5, "value": 0.2},
+                {"time": 2.0, "value": 0.4},
+            ],
+            "Microwave": [
+                {"time": 0.0, "value": 0.5 + 0.5j},
+                {"time": 1.0, "value": 0.3},
+                {"time": 2.0, "value": 0.2 - 0.3j},
+            ],
+        }
     """
 
     plots_data: list[Any] = []
@@ -404,25 +408,27 @@ def plot_sequences(sequences: dict, *, figure: plt.Figure):
         rotation. For example, a pi X-rotation is represented by the complex
         number 3.14+0.j, whereas a pi Y-rotation is 0.+3.14j. The argument of the
         complex number is plotted separately as the azimuthal angle.
-        For example, the following ``sequences`` inputs would be valid ::
-
-            sequences={
-              'X': [
-                {'offset': 0.0, 'rotation': 0.1},
-                {'offset': 0.5, 'rotation': 0.3},
-                {'offset': 1.5, 'rotation': 0.2},
-                {'offset': 2.0, 'rotation': 0.4},
-              ],
-              'XY': [
-                {'offset': 0.0, 'rotation': 0.5 + 0.5j},
-                {'offset': 1.0, 'rotation': 0.3},
-                {'offset': 2.0, 'rotation': 0.2 - 0.3j},
-              ],
-            }
-
     figure : matplotlib.figure.Figure, optional
         A matplotlib Figure in which to place the plots.
         If passed, its dimensions and axes will be overridden.
+
+    Notes
+    -----
+    As an example, the following is valid ``sequences`` input ::
+
+        sequences={
+            "X": [
+                {"offset": 0.0, "rotation": 0.1},
+                {"offset": 0.5, "rotation": 0.3},
+                {"offset": 1.5, "rotation": 0.2},
+                {"offset": 2.0, "rotation": 0.4},
+            ],
+            "XY": [
+                {"offset": 0.0, "rotation": 0.5 + 0.5j},
+                {"offset": 1.0, "rotation": 0.3},
+                {"offset": 2.0, "rotation": 0.2 - 0.3j},
+            ],
+        }
     """
 
     check_argument(
